@@ -30,52 +30,39 @@ public class MVSFTPEntryParserTest extends FTPParseTestFramework {
 
     private static final String[] goodsamplesDatasetList = {
             /* Note, if the string begins with SAVE, the parsed entry is stored in the List saveftpfiles */
-            //  "Volume Unit    Referred Ext Used Recfm Lrecl BlkSz Dsorg Dsname",
+            // "Volume Unit Referred Ext Used Recfm Lrecl BlkSz Dsorg Dsname",
             "SAVE00 3390   2004/06/23  1    1  FB     128  6144  PS    INCOMING.RPTBM023.D061704",
             "SAVE01 3390   2004/06/23  1    1  FB     128  6144  PO    INCOMING.RPTBM024.D061704",
             "SAVE02 3390   2004/06/23  1    1  FB     128  6144  PO-E  INCOMING.RPTBM025.D061704",
-            "PSMLC1 3390   2005/04/04  1    1  VB   27994 27998  PS    file3.I",
-            "PSMLB9 3390   2005/04/04  1    1  VB   27994 27998  PS    file4.I.BU",
-            "PSMLB6 3390   2005/04/05  1    1  VB   27994 27998  PS    file3.I.BU",
-            "PSMLC6 3390   2005/04/05  1    1  VB   27994 27998  PS    file6.I",
-            "PSMLB7 3390   2005/04/04  1    1  VB   27994 27998  PS    file7.O",
-            "PSMLC6 3390   2005/04/05  1    1  VB   27994 27998  PS    file7.O.BU",
+            "PSMLC1 3390   2005/04/04  1    1  VB   27994 27998  PS    file3.I", "PSMLB9 3390   2005/04/04  1    1  VB   27994 27998  PS    file4.I.BU",
+            "PSMLB6 3390   2005/04/05  1    1  VB   27994 27998  PS    file3.I.BU", "PSMLC6 3390   2005/04/05  1    1  VB   27994 27998  PS    file6.I",
+            "PSMLB7 3390   2005/04/04  1    1  VB   27994 27998  PS    file7.O", "PSMLC6 3390   2005/04/05  1    1  VB   27994 27998  PS    file7.O.BU",
             "FPFS49 3390   2004/06/23  1    1  FB     128  6144  PO-E  INCOMING.RPTBM026.D061704",
             "FPFS41 3390   2004/06/23  1    1  FB     128  6144  PS    INCOMING.RPTBM056.D061704",
             "FPFS25 3390   2004/06/23  1    1  FB     128  6144  PS    INCOMING.WTM204.D061704",
             "PEX26F 3390   2017/07/03  115807  FB   29600 29600  PS    INCOMING.FIN.D170630.T160630",
-            "VVVVVV 3390   2020/04/18 1    60   U   32760 32760  PO    NAME"
-        };
+            "VVVVVV 3390   2020/04/18 1    60   U   32760 32760  PO    NAME" };
 
     private static final String[] goodsamplesMemberList = {
             /* Note, if the string begins with SAVE, the parsed entry is stored in the List saveftpfiles */
-            "Name      VV.MM   Created       Changed      Size  Init   Mod   Id",
-            "SAVE03    01.03 2002/09/12 2002/10/11 09:37    11    11     0 KIL001",
+            "Name      VV.MM   Created       Changed      Size  Init   Mod   Id", "SAVE03    01.03 2002/09/12 2002/10/11 09:37    11    11     0 KIL001",
             "SAVE04                                                              ", // no statistics
-            "TBSHELF1  01.03 2002/09/12 2002/10/11 09:37    11    11     0 KIL001",
-            "TBSHELF2  01.03 2002/09/12 2002/10/11 09:37    11    11     0 KIL001",
-            "TBSHELF3  01.03 2002/09/12 2002/10/11 09:37    11    11     0 KIL001",
-            "TBSHELF4  01.03 2002/09/12 2002/10/11 09:37    11    11     0 KIL001", };
+            "TBSHELF1  01.03 2002/09/12 2002/10/11 09:37    11    11     0 KIL001", "TBSHELF2  01.03 2002/09/12 2002/10/11 09:37    11    11     0 KIL001",
+            "TBSHELF3  01.03 2002/09/12 2002/10/11 09:37    11    11     0 KIL001", "TBSHELF4  01.03 2002/09/12 2002/10/11 09:37    11    11     0 KIL001", };
 
     private static final String[] goodsamplesJES1List = { /* no header for JES1 (JES Interface level 1) */
-    /* Note, if the string begins with SAVE, the parsed entry is stored in the List saveftpfiles */
-    "IBMUSER1  JOB01906  OUTPUT    3 Spool Files", };
+            /* Note, if the string begins with SAVE, the parsed entry is stored in the List saveftpfiles */
+            "IBMUSER1  JOB01906  OUTPUT    3 Spool Files", };
 
     private static final String[] goodsamplesJES2List = { /* JES2 (JES Interface level 2) */
             /* Note, if the string begins with SAVE, the parsed entry is stored in the List saveftpfiles */
-            //"JOBNAME  JOBID    OWNER    STATUS CLASS",
-            "IBMUSER2 JOB01906 IBMUSER  OUTPUT A        RC=0000 3 spool files",
-            "IBMUSER  TSU01830 IBMUSER  OUTPUT TSU      ABEND=522 3 spool files", };
+            // "JOBNAME JOBID OWNER STATUS CLASS",
+            "IBMUSER2 JOB01906 IBMUSER  OUTPUT A        RC=0000 3 spool files", "IBMUSER  TSU01830 IBMUSER  OUTPUT TSU      ABEND=522 3 spool files", };
 
-    private static final String[] goodsamplesUnixList = {
-            "total 1234",
-            "-rwxr-xr-x   2 root     root         4096 Mar  2 15:13 zxbox",
-            "drwxr-xr-x   2 root     root         4096 Aug 24  2001 zxjdbc",
-            };
+    private static final String[] goodsamplesUnixList = { "total 1234", "-rwxr-xr-x   2 root     root         4096 Mar  2 15:13 zxbox",
+            "drwxr-xr-x   2 root     root         4096 Aug 24  2001 zxjdbc", };
 
-    private static final String[] badsamples = {
-            "MigratedP201.$FTXPBI1.$CF2ITB.$AAB0402.I",
-            "PSMLC133902005/04/041VB2799427998PSfile1.I", "file2.O", };
+    private static final String[] badsamples = { "MigratedP201.$FTXPBI1.$CF2ITB.$AAB0402.I", "PSMLC133902005/04/041VB2799427998PSfile1.I", "file2.O", };
 
     /**
      * @see junit.framework.TestCase#TestCase(String)
@@ -85,20 +72,11 @@ public class MVSFTPEntryParserTest extends FTPParseTestFramework {
 
     }
 
-    /* (non-Javadoc)
-     * @see org.apache.commons.net.ftp.parser.CompositeFTPParseTestFramework#getBadListings()
-     */
     @Override
-    protected String[] getBadListing() {
-        return badsamples;
-    }
-
-    /* (non-Javadoc)
-     * @see org.apache.commons.net.ftp.parser.CompositeFTPParseTestFramework#getGoodListings()
-     */
-    @Override
-    protected String[] getGoodListing() {
-        return goodsamplesDatasetList;
+    public void doAdditionalGoodTests(final String test, final FTPFile f) {
+        assertNotNull("Could not parse raw listing in " + test, f.getRawListing());
+        assertNotNull("Could not parse name in " + test, f.getName());
+        // some tests don't produce any further details
     }
 
     protected List<String[]> getAllGoodListings() {
@@ -111,6 +89,25 @@ public class MVSFTPEntryParserTest extends FTPParseTestFramework {
         return l;
     }
 
+    /*
+     * (non-Javadoc)
+     *
+     * @see org.apache.commons.net.ftp.parser.CompositeFTPParseTestFramework#getBadListings()
+     */
+    @Override
+    protected String[] getBadListing() {
+        return badsamples;
+    }
+
+    /*
+     * (non-Javadoc)
+     *
+     * @see org.apache.commons.net.ftp.parser.CompositeFTPParseTestFramework#getGoodListings()
+     */
+    @Override
+    protected String[] getGoodListing() {
+        return goodsamplesDatasetList;
+    }
 
     /**
      * @see org.apache.commons.net.ftp.parser.FTPParseTestFramework#getParser()
@@ -120,11 +117,16 @@ public class MVSFTPEntryParserTest extends FTPParseTestFramework {
         return new MVSFTPEntryParser();
     }
 
+    @Override
+    public void testDefaultPrecision() {
+        // TODO Not sure what dates are parsed
+    }
+
     /*
-     * note the testGoodListing has to be the first test invoked, because
-     * some FTPFile entries are saved for the later tests
+     * note the testGoodListing has to be the first test invoked, because some FTPFile entries are saved for the later tests
      *
      * (non-Javadoc)
+     *
      * @see org.apache.commons.net.ftp.parser.FTPParseTestFramework#testGoodListing()
      */
     @Override
@@ -140,17 +142,6 @@ public class MVSFTPEntryParserTest extends FTPParseTestFramework {
         }
     }
 
-    public void testMemberListing() {
-        final MVSFTPEntryParser parser = new MVSFTPEntryParser();
-        parser.setType(MVSFTPEntryParser.MEMBER_LIST_TYPE);
-        parser.setRegex(MVSFTPEntryParser.MEMBER_LIST_REGEX);
-        for (final String test : goodsamplesMemberList) {
-            final FTPFile f = parser.parseFTPEntry(test);
-            assertNotNull("Failed to parse " + test, f);
-            doAdditionalGoodTests(test, f);
-        }
-    }
-
     public void testJesLevel1Listing() {
         final MVSFTPEntryParser parser = new MVSFTPEntryParser();
         parser.setType(MVSFTPEntryParser.JES_LEVEL_1_LIST_TYPE);
@@ -173,17 +164,14 @@ public class MVSFTPEntryParserTest extends FTPParseTestFramework {
         }
     }
 
-    public void testUnixListings() {
+    public void testMemberListing() {
         final MVSFTPEntryParser parser = new MVSFTPEntryParser();
-        final List<String> list = new ArrayList<>();
-        Collections.addAll(list, goodsamplesUnixList);
-        parser.preParse(list);
-        for (final String test : list) {
+        parser.setType(MVSFTPEntryParser.MEMBER_LIST_TYPE);
+        parser.setRegex(MVSFTPEntryParser.MEMBER_LIST_REGEX);
+        for (final String test : goodsamplesMemberList) {
             final FTPFile f = parser.parseFTPEntry(test);
             assertNotNull("Failed to parse " + test, f);
-            assertNotNull("Failed to parse name " + test, f.getName());
-            assertNotNull("Failed to parse group " + test, f.getGroup());
-            assertNotNull("Failed to parse user " + test, f.getUser());
+            doAdditionalGoodTests(test, f);
         }
     }
 
@@ -193,21 +181,21 @@ public class MVSFTPEntryParserTest extends FTPParseTestFramework {
         parser.setType(MVSFTPEntryParser.FILE_LIST_TYPE);
         parser.setRegex(MVSFTPEntryParser.FILE_LIST_REGEX);
 
-        FTPFile file = parser
-                .parseFTPEntry("SAVE01 3390   2004/06/23  1    1  FB     128  6144  PO    INCOMING.RPTBM024.D061704");
+        FTPFile file = parser.parseFTPEntry("SAVE01 3390   2004/06/23  1    1  FB     128  6144  PO    INCOMING.RPTBM024.D061704");
         assertNotNull("Could not parse entry.", file);
         assertTrue("Should have been a directory.", file.isDirectory());
         assertEquals("INCOMING.RPTBM024.D061704", file.getName());
 
-        file = parser
-                .parseFTPEntry("SAVE02 3390   2004/06/23  1    1  FB     128  6144  PO-E  INCOMING.RPTBM025.D061704");
+        file = parser.parseFTPEntry("SAVE02 3390   2004/06/23  1    1  FB     128  6144  PO-E  INCOMING.RPTBM025.D061704");
         assertNotNull("Could not parse entry.", file);
         assertTrue("Should have been a directory.", file.isDirectory());
         assertEquals("INCOMING.RPTBM025.D061704", file.getName());
 
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     *
      * @see org.apache.commons.net.ftp.parser.FTPParseTestFramework#testParseFieldsOnFile()
      */
     @Override
@@ -242,20 +230,22 @@ public class MVSFTPEntryParserTest extends FTPParseTestFramework {
 
     }
 
-    @Override
-    public void doAdditionalGoodTests(final String test, final FTPFile f) {
-        assertNotNull("Could not parse raw listing in " + test, f.getRawListing());
-        assertNotNull("Could not parse name in " + test, f.getName());
-        // some tests don't produce any further details
-    }
-
-    @Override
-    public void testDefaultPrecision() {
-        // TODO Not sure what dates are parsed
-    }
-
     @Override
     public void testRecentPrecision() {
         // TODO Auto-generated method stub
     }
+
+    public void testUnixListings() {
+        final MVSFTPEntryParser parser = new MVSFTPEntryParser();
+        final List<String> list = new ArrayList<>();
+        Collections.addAll(list, goodsamplesUnixList);
+        parser.preParse(list);
+        for (final String test : list) {
+            final FTPFile f = parser.parseFTPEntry(test);
+            assertNotNull("Failed to parse " + test, f);
+            assertNotNull("Failed to parse name " + test, f.getName());
+            assertNotNull("Failed to parse group " + test, f.getGroup());
+            assertNotNull("Failed to parse user " + test, f.getUser());
+        }
+    }
 }
